@@ -1,6 +1,6 @@
 /*
  * Rjb - Ruby <-> Java Bridge
- * Copyright(c) 2004,2005,2006,2007,2008,2009,2010,2011,2012,2014 arton
+ * Copyright(c) 2004,2005,2006,2007,2008,2009,2010,2011,2012,2014-2016 arton
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,7 +14,7 @@
  *
  */
 
-#define RJB_VERSION "1.5.3"
+#define RJB_VERSION "1.5.5"
 
 #include "ruby.h"
 #include "extconf.h"
@@ -1159,6 +1159,17 @@ static void rv2jarray(JNIEnv* jenv, VALUE val, jvalue* jv, const char* psig, int
                 rb_str_append(val, src);
             }
         }
+        else if (TYPE(val) == T_ARRAY && *(psig + 1) == 'C')
+        {
+            int i;
+            jsize len = (*jenv)->GetArrayLength(jenv, jv->l);
+            jchar* p = (*jenv)->GetCharArrayElements(jenv, jv->l, NULL);
+            rb_ary_clear(val);
+            for (i = 0; i < len; i++, p++)
+            {
+                rb_ary_push(val, INT2FIX(*p));
+            }
+        }
 	(*jenv)->DeleteLocalRef(jenv, jv->l);
     }
     else
